@@ -98,8 +98,15 @@ class FacebookMiddleware():
                         user.oauth_token.save()
 
                     user.save()
-
-                user.oauth_token.extend()
+                
+                # Attempt to extend the OAuth token, but ignore exceptions raised by
+                # bug #102727766518358 in the Facebook Platform.
+                #
+                # http://developers.facebook.com/bugs/102727766518358/
+                try:
+                    user.oauth_token.extend()
+                except:
+                    pass
 
                 request.facebook.user = user
 
